# -*- coding: utf-8 -*-

import json
import shutil
from .exceptions import CyberarkException, CyberarkAPIException
from .abstract import Bastion


class Platform:
    def __init__(self, epv: Bastion):
        self.epv = epv
        self.session = self.epv.session

    def get_platforms(self):
        url, head = self.epv.get_url("API/Platforms/Targets")

        try:
            req = self.session.get(url, headers=head, **self.epv.reqparms)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content)

        platforms = json.loads(req.content)
        return platforms["Platforms"]


    def del_plaform(self, pfid):
        url, head = self.epv.get_url("API/Platforms/Targets/"+str(pfid))

        try:
            req = self.session.delete(url, headers=head, **self.epv.reqparms)
            #req = epv.session.get(url, headers=head, params=data, **self.epv.reqparms)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 204:
            content = json.loads(req.content)
            #raise CyberarkAPIException(content["ErrorMessage"])
            raise CyberarkAPIException(content)

        return True

    def export_platform(self, pfid: str, outdir: str):
        """Export platform files to outdir (existing directory)"""
        url, head = self.epv.get_url("API/Platforms/"+str(pfid)+"/Export")

        try:
            req = self.session.post(url, headers=head, data=None, **self.epv.reqparms, stream=True)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content["Message"])

        with open(outdir+"/"+pfid+".zip", "wb") as pf_file:
            shutil.copyfileobj(req.raw, pf_file)

        return True
